# mypy-boto3-lexv2-models

[![PyPI - mypy-boto3-lexv2-models](https://img.shields.io/pypi/v/mypy-boto3-lexv2-models.svg?color=blue)](https://pypi.org/project/mypy-boto3-lexv2-models)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-lexv2-models.svg?color=blue)](https://pypi.org/project/mypy-boto3-lexv2-models)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.LexModelsV2 1.17.35](https://boto3.amazonaws.com/v1/documentation/api/1.17.35/reference/services/lexv2-models.html#LexModelsV2) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-lexv2-models](#mypy-boto3-lexv2-models)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `LexModelsV2` service.

```bash
python -m pip install boto3-stubs[lexv2-models]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[lexv2-models]` in your environment: `python -m pip install 'boto3-stubs[lexv2-models]'`

Both type checking and auto-complete should work for `LexModelsV2` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[lexv2-models]` in your environment: `python -m pip install 'boto3-stubs[lexv2-models]'`

Both type checking and auto-complete should work for `LexModelsV2` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[lexv2-models]` in your environment: `python -m pip install 'boto3-stubs[lexv2-models]'`
- Run `mypy` as usual

Type checking should work for `LexModelsV2` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[lexv2-models]` in your environment: `python -m pip install 'boto3-stubs[lexv2-models]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `LexModelsV2` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`LexModelsV2Client` provides annotations for `boto3.client("lexv2-models")`.

```python
import boto3

from mypy_boto3_lexv2_models import LexModelsV2Client

client: LexModelsV2Client = boto3.client("lexv2-models")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: LexModelsV2Client = session.client("lexv2-models")
```








### Typed dictionations

`mypy_boto3_lexv2_models.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_lexv2_models.type_defs import (
    AudioLogDestinationTypeDef,
    AudioLogSettingTypeDef,
    BotAliasHistoryEventTypeDef,
    BotAliasLocaleSettingsTypeDef,
    BotAliasSummaryTypeDef,
    BotLocaleHistoryEventTypeDef,
    BotLocaleSummaryTypeDef,
    BotSummaryTypeDef,
    BotVersionLocaleDetailsTypeDef,
    BotVersionSummaryTypeDef,
    BuiltInIntentSummaryTypeDef,
    BuiltInSlotTypeSummaryTypeDef,
    ButtonTypeDef,
    CloudWatchLogGroupLogDestinationTypeDef,
    CodeHookSpecificationTypeDef,
    ConversationLogSettingsTypeDef,
    CustomPayloadTypeDef,
    DataPrivacyTypeDef,
    DialogCodeHookSettingsTypeDef,
    FulfillmentCodeHookSettingsTypeDef,
    ImageResponseCardTypeDef,
    InputContextTypeDef,
    IntentClosingSettingTypeDef,
    IntentConfirmationSettingTypeDef,
    IntentSummaryTypeDef,
    KendraConfigurationTypeDef,
    LambdaCodeHookTypeDef,
    MessageGroupTypeDef,
    MessageTypeDef,
    ObfuscationSettingTypeDef,
    OutputContextTypeDef,
    PlainTextMessageTypeDef,
    PromptSpecificationTypeDef,
    ResponseSpecificationTypeDef,
    S3BucketLogDestinationTypeDef,
    SSMLMessageTypeDef,
    SampleUtteranceTypeDef,
    SampleValueTypeDef,
    SentimentAnalysisSettingsTypeDef,
    SlotDefaultValueSpecificationTypeDef,
    SlotDefaultValueTypeDef,
    SlotPriorityTypeDef,
    SlotSummaryTypeDef,
    SlotTypeSummaryTypeDef,
    SlotTypeValueTypeDef,
    SlotValueElicitationSettingTypeDef,
    SlotValueRegexFilterTypeDef,
    SlotValueSelectionSettingTypeDef,
    StillWaitingResponseSpecificationTypeDef,
    TextLogDestinationTypeDef,
    TextLogSettingTypeDef,
    VoiceSettingsTypeDef,
    WaitAndContinueSpecificationTypeDef,
    BotFilterTypeDef,
    BotLocaleFilterTypeDef,
    BotLocaleSortByTypeDef,
    BotSortByTypeDef,
    BotVersionSortByTypeDef,
    BuildBotLocaleResponseTypeDef,
    BuiltInIntentSortByTypeDef,
    BuiltInSlotTypeSortByTypeDef,
    CreateBotAliasResponseTypeDef,
    CreateBotLocaleResponseTypeDef,
    CreateBotResponseTypeDef,
    CreateBotVersionResponseTypeDef,
    CreateIntentResponseTypeDef,
    CreateSlotResponseTypeDef,
    CreateSlotTypeResponseTypeDef,
    DeleteBotAliasResponseTypeDef,
    DeleteBotLocaleResponseTypeDef,
    DeleteBotResponseTypeDef,
    DeleteBotVersionResponseTypeDef,
    DescribeBotAliasResponseTypeDef,
    DescribeBotLocaleResponseTypeDef,
    DescribeBotResponseTypeDef,
    DescribeBotVersionResponseTypeDef,
    DescribeIntentResponseTypeDef,
    DescribeSlotResponseTypeDef,
    DescribeSlotTypeResponseTypeDef,
    IntentFilterTypeDef,
    IntentSortByTypeDef,
    ListBotAliasesResponseTypeDef,
    ListBotLocalesResponseTypeDef,
    ListBotVersionsResponseTypeDef,
    ListBotsResponseTypeDef,
    ListBuiltInIntentsResponseTypeDef,
    ListBuiltInSlotTypesResponseTypeDef,
    ListIntentsResponseTypeDef,
    ListSlotTypesResponseTypeDef,
    ListSlotsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    SlotFilterTypeDef,
    SlotSortByTypeDef,
    SlotTypeFilterTypeDef,
    SlotTypeSortByTypeDef,
    UpdateBotAliasResponseTypeDef,
    UpdateBotLocaleResponseTypeDef,
    UpdateBotResponseTypeDef,
    UpdateIntentResponseTypeDef,
    UpdateSlotResponseTypeDef,
    UpdateSlotTypeResponseTypeDef,
)

def get_structure() -> AudioLogDestinationTypeDef:
    return {
      ...
    }
```
